@@ -26,9 +26,9 @@ class StyleModifierPluginModel(CMSPlugin):
                      (".jumbotron", _("jumbo banner")),
                      (".container", _("containers")),
                      (".btn", _("buttons")),
-                     (".btn:hover, .btn:active, .btn.active, .btn.disabled, .btn[disabled]", _("active buttons")),
-                     (".btn-primary", _("primary buttons")),
-                     (".btn-primary:hover, .btn-primary:active, .btn-primary.active, .btn-primary.disabled, .btn-primary[disabled]", _("active primary buttons")),
+                     (".btn:hover, .btn:active, .btn.focus, .btn.disabled, .btn[disabled]", _("active buttons")),
+                     (".btn.btn-primary", _("primary buttons")),
+                     (".btn.btn-primary:hover, .btn.btn-primary:active, .btn.btn-primary.focus, .btn.btn-primary.disabled, .btn.btn-primary[disabled]", _("active primary buttons")),
                      (".dropdown-menu", _("dropdown menus")),
                      (".sidenav a", _("side navigation menu")),
                      (".sidenav .active a", _("active side nav menu")),
